==> haskell-wai-cors-0.2.7-432-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-cors
version:              0.2.7
visibility:           public
id:                   wai-cors-0.2.7-AXEwMTW1q2kIz1ePWz7aZ0
key:                  wai-cors-0.2.7-AXEwMTW1q2kIz1ePWz7aZ0
license:              MIT
copyright:
    (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
    (c) 2014 AlephCloud Systems, Inc.

maintainer:           Lars Kuhtz <lakuhtz@gmail.com>
author:               Lars Kuhtz <lakuhtz@gmail.com>
homepage:             https://github.com/larskuhtz/wai-cors
synopsis:             CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.

category:             HTTP, Network, Web, Wai
abi:                  336ba012b3bddbc17eaec4bc531b748a
exposed:              True
exposed-modules:      Network.Wai.Middleware.Cors
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-cors-0.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-cors-0.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-cors
hs-libraries:         HSwai-cors-0.2.7-AXEwMTW1q2kIz1ePWz7aZ0
depends:
    attoparsec-0.14.4-fEKSJrOU814GdIIzzkkyx base-4.17.2.1
    base-unicode-symbols-0.2.4.2-DGP2ohBQv5PB4jg5C9PUqH
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-K9RqmTXohzcArWLcYT3z8C
    http-types-0.12.4-IhtLMXP6VlH4EvGJYn8uz7 mtl-2.2.2
    transformers-0.5.6.2 wai-3.2.4-EOBJdwgqwP2ZRndhZ2MHb

haddock-interfaces:   /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html:         /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-cors-0.2.7-433-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-cors
version:              0.2.7
visibility:           public
id:                   wai-cors-0.2.7-GFyBjjGyTZYDPu08iwgIS3
key:                  wai-cors-0.2.7-GFyBjjGyTZYDPu08iwgIS3
license:              MIT
copyright:
    (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
    (c) 2014 AlephCloud Systems, Inc.

maintainer:           Lars Kuhtz <lakuhtz@gmail.com>
author:               Lars Kuhtz <lakuhtz@gmail.com>
homepage:             https://github.com/larskuhtz/wai-cors
synopsis:             CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.

category:             HTTP, Network, Web, Wai
abi:                  220fbe3bd5be26474f89681a9d26a3fa
exposed:              True
exposed-modules:      Network.Wai.Middleware.Cors
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-cors-0.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-cors-0.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-cors
hs-libraries:         HSwai-cors-0.2.7-GFyBjjGyTZYDPu08iwgIS3
depends:
    attoparsec-0.14.4-K4GZo37SQ24KyCrR1RSIsH base-4.17.2.1
    base-unicode-symbols-0.2.4.2-DGP2ohBQv5PB4jg5C9PUqH
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-5l2QOpNdY1A6hVaz3nH17n
    http-types-0.12.4-1Pq1Zy5bmQBJRy3r5PsBE mtl-2.2.2
    transformers-0.5.6.2 wai-3.2.4-84onj9aucoXBC5yY5F84Os

haddock-interfaces:   /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html:         /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
